=========
Tutorials
=========

Here you will find the jupyter notebook tutorials. It is recommended
that you go through the tutorials yourself, but for quick reference a
version of each tutorial is available here.

.. toctree::
    :maxdepth: 1

    GettingStarted
    GettingStartedJAX
    GroupModels
    FittingMethods
    ModelZoo
    BasicPSFModels
    JointModels
    ImageAlignment
    FittingPriors
    PoissonLikelihood
    CustomModels
    FunctionalInterface
    GravitationalLensing
    AdvancedPSFModels
    ImageTypes
    ConstrainedModels
